// Demo 9

//  The Continuing Saga of Sally's Lemonade Stand
//  A Java Applet and Keeping a Running Total Demo
//
//          by Charles W. Neville, 1998
//       Copyright Charles W. Neville, 1998

// Scenario: Little Sally is a very precocious five year old who runs a 
// lemonade stand.  She is also your kid sister.  In our last demo (demo 8),
// we wrote a screen based Java application for her so she could keep track
// of her daily sales receipts.  Sally was quite pleased, but she quickly
// realized that a Graphic User Interface based program would be much more
// fun to use, and easier too!  So she asks you to modify your screen based
// application so it would use windows and textfields and things.
//
// After a few moments thought, you realize that a GUI Applet will not only
// be easier for her to use, but actually easier for you to write.  (This is
// an unusual situation, but it happens from time to time.)  The reason is
// that you no longer have to implement reading and processing up to a
// stopping signal with a while loop, because the system will keep the program
// running until Sally clicks on the close button at the top of the Applet 
// window.  Neat huh!  Let the system do some of the work, but take all the 
// credit for yourself!  (I hope you don't do this around Sally though, 
// because she would be VERY DISAPPOINTED in you, her admired older brother
// or sister, when she discovered that you had been dishonest.)
//
// Sally will be very happy, because she can enter each sale into a TextField,
// and easily edit it if she makes a mistake.  She no longer has to enter the
// -999 stopping signal at the end of the day to get her totals, because you 
// will arrange for the current totals to be drawn on the Applet Panel each
// time she enters a new sale.  Sally will also show her new Applet off to
// her friends, and brag to them about how clever you are.
//
// But you did gain something from writing the clunky screen based application 
// (demo 8).  You learned how to keep a running total; you learned how to
// do keyboard based input in a screen based application (very useful later
// when we get to files), and you learned how to READ AND PROCESS UP TO
// A STOPPING SIGNAL.  You will find this is useful and needed in EVERY
// computer science course you take from now on, all the way up to Compiler
// Design.

import java.awt.*;
import java.awt.event.*;
import java.applet.Applet;

// no need to import java.io.* because we get our input from TextFields,
// not from the keyboard in a screen-based application.  In some sense,
// java.awt.event.* takes the place of java.io here.

public class SallyApplet extends Applet implements ActionListener {

   int salePrice, count, total;

   Label prompt;     // prompt on Applet Panel for TextField input
   TextField input;  // where Sally enters current sale price

   // no need for a stopping signal, so no need for
   // declaration final int stoppingSignal = -999;

   // init() is a good place to initialize variables in an Applet
   //        and add things to the Applet Panel.
   public void init() {

       // initialize variables
       count = 0;  // always set count to 0 when you start counting
       total = 0;  // always set total to 0 when you start keeping a
                   // running total

       salePrice = 0;

       // create new instances of Label and TextField classes
       //        (Label and TextField objects).
       prompt = new Label ( "Sale Price:" );
       input = new TextField(9);

       // add Label and TextField to Applet Panel
       add( prompt );
       add( input );

      // Register this object as the ActionListener (ActionEvent processor)
      //   for input.  (An action event happens, for example, when the
      //   Enter key is pressed.  Leaving this out causes your application not 
      //   to respond when the user presses the Enter key.
      input.addActionListener(this);  // this is a keyword referring to
                                      // the current object, ie. this object. 
   }

   public void paint( Graphics g ) {

      g.drawString( "Sales Count: " + count, 25, 140 );
      g.drawString( "Total Sales: " + total, 25, 160 );
      g.drawString( "Keep Up the Good Work, Sally!", 25, 180 );
   }

   // When Sally presses the Enter key while in TextField input, we
   // do this to process her input.
   public void actionPerformed( ActionEvent e ) {

       // read the salePrice from TextField input
       salePrice = Integer.parseInt(input.getText());

       // because we don't want to reuse a variable several times in paint,
       // it is better to do the calculations here in actionPerformed, rather
       // than in paint as we did in the ArithOps demos (demos 6 and 7).
       total = total + salePrice;
       count = count + 1;

       // force Applet Panel to be repainted so results will be painted.
       repaint();
   }    
}